nx.Iterable - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.Iterable Class

Module: nx

- Index
- Methods
- Properties

## Item Index

### Methods

- each
- getIterator static
- toArray static
- toArray

### Properties

- count

## Methods

### `each`

(

- `callback`
- `context`

)

#### Parameters:

- `callback` Object
- `context` Object

### `getIterator`

(

- `iter`

)
Function static

Get the iteration function from an iterable object.

#### Parameters:

- `iter` Object | Array | nx.Iterable

#### Returns:

Function:

### `toArray`

(

- `iter`

)
Array static

Convert the iterable object to an array.

#### Parameters:

- `iter` Object | Array | nx.Iterable

#### Returns:

Array:

### `toArray`

() Array

#### Returns:

Array:

## Properties

### `count`

Number